@@ -6,11 +6,11 @@ DEFAULT_SAMPLER = "k_dpmpp_2m"
 
 DEFAULT_NEGATIVE_PROMPT = (
     "(weird eyes:1.5), smudged face, (blurred face:1.5), (poorly drawn face:1.5), mutation, mutilation, cloned face, (strange mouth:1.5), (duplicated face:2.0), "
-    "(Ugly:1.5), *duplication:1.5), duplicates, mutilation, deformed, mutilated, (mutation:1.5), (twisted body:1.5), (disfigured:1.5), (bad anatomy:1.5), "
+    "(Ugly:1.5), (duplication:1.5), duplicates, mutilation, deformed, mutilated, (mutation:1.5), (twisted body:1.5), (disfigured:1.5), (bad anatomy:1.5), "
     "(poorly drawn hands:1.5), (extra limbs:1.5), (malformed limbs:1.5), (missing arms:1.5), (extra arms:1.5), (missing legs:1.5), (extra legs:1.5), (mutated hands:1.5), "
     "(extra hands:1.5), (fused fingers:1.5), (missing fingers:1.5), extra fingers, long neck, small head, closed eyes, rolling eyes, "
-    "grainy, blurred, blurry, writing, calligraphy, text, (watermark:1.5), bad art, "
-    "(out of frame:1.5), (extra fingers:1.5), (mutated hands:1.5), (porn:1.5), (child abuse:1.5), (horrific images:1.5), (dead bodies:1.5), ",
+    "grainy, blurred, blurry, writing, calligraphy, (text:3.0), (watermark:1.5), bad art, "
+    "(out of frame:1.5), (extra fingers:1.5), (mutated hands:1.5), (porn:1.5), (child abuse:1.5), (horrific images:1.5), (dead bodies:1.5), "
     "(watermark:1.5), child, lowres, bad anatomy, bad hands, text, error, (missing fingers:1.5), extra digit, fewer digits, cropped, "
     "worst quality, (low quality:1.5), normal quality, jpeg artifacts, (signature:1.5), watermark, username, blurry, (bad feet:1.5), bad lighting, "
     "bad coloring, bad perspective, (bad focus:1.5), bad design, bad eyes, bad hair, bad nose, bad mouth, bad ears, bad teeth, bad tongue, bad lips, "
